@@ -45,9 +45,14 @@ class GQLHandler(HandlerGQL):
         # create GQLClient
         gqlClient = GraphqlClient(endpoint=ENDPOINT, headers=requestHeaders)
         # execute QUERY|MUTATION
-        data: dict[str, Any] = await gqlClient.ha_execute_async(
-            query=query, variables=variables, operation_name=operation_name, session=self._session
-        )
+        if self._session:
+            data: dict[str, Any] = await gqlClient.ha_execute_async(
+                query=query, variables=variables, operation_name=operation_name, session=self._session
+            )
+        else:
+            data: dict[str, Any] = await gqlClient.execute_async(
+                query=query, variables=variables, operation_name=operation_name
+            )
         return data
 
     async def runAuthorizedGqlQuery_a(
@@ -112,7 +117,7 @@ class GQLHandler(HandlerGQL):
         if errors:
             self.errors.append({"function": "askWatchLocate", "errors": errors})
         res: dict[str, Any] = data.get("data", {})
-        if res["askWatchLocate"] is not None:
+        if res.get("askWatchLocate", None) is not None:
             return res
         return {"askWatchLocate": False}
 
